# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation
import winrt.windows.foundation.collections as windows_foundation_collections
import winrt.windows.ui.text as windows_ui_text
import winui3.microsoft.ui.xaml as microsoft_ui_xaml
import winui3.microsoft.ui.xaml.input as microsoft_ui_xaml_input
import winui3.microsoft.ui.xaml.media as microsoft_ui_xaml_media

from winui3.microsoft.ui.xaml.documents import LogicalDirection, UnderlineStyle

Self = typing.TypeVar('Self')

@typing.final
class TextRange:
    @_property
    def start_index(self) -> winrt.system.Int32: ...
    @_property
    def length(self) -> winrt.system.Int32: ...
    def __new__(cls, start_index: winrt.system.Int32 = 0, length: winrt.system.Int32 = 0) -> TextRange: ...
    def __replace__(self, /, **changes: typing.Any) -> TextRange: ...
    def unpack(self) -> typing.Tuple[winrt.system.Int32, winrt.system.Int32]: ...

class Block_Static(TextElement_Static):
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Block::get_HorizontalTextAlignmentProperty()
    @_property
    @typing.final
    def horizontal_text_alignment_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Block::get_LineHeightProperty()
    @_property
    @typing.final
    def line_height_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Block::get_LineStackingStrategyProperty()
    @_property
    @typing.final
    def line_stacking_strategy_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Block::get_MarginProperty()
    @_property
    @typing.final
    def margin_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Block::get_TextAlignmentProperty()
    @_property
    @typing.final
    def text_alignment_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...

class Block(TextElement, metaclass=Block_Static):
    # Microsoft.UI.Xaml.TextAlignment Microsoft.UI.Xaml.Documents.Block::get_TextAlignment()
    @_property
    def text_alignment(self) -> microsoft_ui_xaml.TextAlignment: ...
    # System.Void Microsoft.UI.Xaml.Documents.Block::put_TextAlignment(Microsoft.UI.Xaml.TextAlignment)
    @text_alignment.setter
    @typing.final
    def text_alignment(self, value: microsoft_ui_xaml.TextAlignment) -> None: ...
    # Microsoft.UI.Xaml.Thickness Microsoft.UI.Xaml.Documents.Block::get_Margin()
    @_property
    def margin(self) -> microsoft_ui_xaml.Thickness: ...
    # System.Void Microsoft.UI.Xaml.Documents.Block::put_Margin(Microsoft.UI.Xaml.Thickness)
    @margin.setter
    @typing.final
    def margin(self, value: typing.Union[microsoft_ui_xaml.Thickness, typing.Tuple[winrt.system.Double, winrt.system.Double, winrt.system.Double, winrt.system.Double]]) -> None: ...
    # Microsoft.UI.Xaml.LineStackingStrategy Microsoft.UI.Xaml.Documents.Block::get_LineStackingStrategy()
    @_property
    def line_stacking_strategy(self) -> microsoft_ui_xaml.LineStackingStrategy: ...
    # System.Void Microsoft.UI.Xaml.Documents.Block::put_LineStackingStrategy(Microsoft.UI.Xaml.LineStackingStrategy)
    @line_stacking_strategy.setter
    @typing.final
    def line_stacking_strategy(self, value: microsoft_ui_xaml.LineStackingStrategy) -> None: ...
    # System.Double Microsoft.UI.Xaml.Documents.Block::get_LineHeight()
    @_property
    def line_height(self) -> winrt.system.Double: ...
    # System.Void Microsoft.UI.Xaml.Documents.Block::put_LineHeight(System.Double)
    @line_height.setter
    @typing.final
    def line_height(self, value: winrt.system.Double) -> None: ...
    # Microsoft.UI.Xaml.TextAlignment Microsoft.UI.Xaml.Documents.Block::get_HorizontalTextAlignment()
    @_property
    def horizontal_text_alignment(self) -> microsoft_ui_xaml.TextAlignment: ...
    # System.Void Microsoft.UI.Xaml.Documents.Block::put_HorizontalTextAlignment(Microsoft.UI.Xaml.TextAlignment)
    @horizontal_text_alignment.setter
    @typing.final
    def horizontal_text_alignment(self, value: microsoft_ui_xaml.TextAlignment) -> None: ...

@typing.final
class BlockCollection(winrt.system.Object, winrt._winrt.MutableSequence[Block]):
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[Block]: ...
    @typing.overload
    def __getitem__(self, index: typing.SupportsIndex) -> Block: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winrt.system.Array[Block]: ...
    @typing.overload
    def __delitem__(self, index: typing.SupportsIndex) -> None: ...
    @typing.overload
    def __delitem__(self, index: slice) -> None: ...
    @typing.overload
    def __setitem__(self, index: typing.SupportsIndex, value: Block) -> None: ...
    @typing.overload
    def __setitem__(self, index: slice, value: typing.Iterable[Block]) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.BlockCollection::Append(Microsoft.UI.Xaml.Documents.Block)
    def append(self, value: Block, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.BlockCollection::Clear()
    def clear(self) -> None: ...
    # Windows.Foundation.Collections.IIterator`1<Microsoft.UI.Xaml.Documents.Block> Microsoft.UI.Xaml.Documents.BlockCollection::First()
    def first(self) -> windows_foundation_collections.IIterator[Block]: ...
    # Microsoft.UI.Xaml.Documents.Block Microsoft.UI.Xaml.Documents.BlockCollection::GetAt(System.UInt32)
    def get_at(self, index: winrt.system.UInt32, /) -> Block: ...
    # System.UInt32 Microsoft.UI.Xaml.Documents.BlockCollection::GetMany(System.UInt32,Microsoft.UI.Xaml.Documents.Block[])
    def get_many(self, start_index: winrt.system.UInt32, items: typing.Union[winrt.system.Array[Block], winrt.system.WriteableBuffer], /) -> winrt.system.UInt32: ...
    # Windows.Foundation.Collections.IVectorView`1<Microsoft.UI.Xaml.Documents.Block> Microsoft.UI.Xaml.Documents.BlockCollection::GetView()
    def get_view(self) -> typing.Sequence[Block]: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.BlockCollection::IndexOf(Microsoft.UI.Xaml.Documents.Block,System.UInt32&)
    def index_of(self, value: Block, /) -> typing.Tuple[bool, winrt.system.UInt32]: ...
    # System.Void Microsoft.UI.Xaml.Documents.BlockCollection::InsertAt(System.UInt32,Microsoft.UI.Xaml.Documents.Block)
    def insert_at(self, index: winrt.system.UInt32, value: Block, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.BlockCollection::RemoveAt(System.UInt32)
    def remove_at(self, index: winrt.system.UInt32, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.BlockCollection::RemoveAtEnd()
    def remove_at_end(self) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.BlockCollection::ReplaceAll(Microsoft.UI.Xaml.Documents.Block[])
    def replace_all(self, items: typing.Union[winrt.system.Array[Block], winrt.system.ReadableBuffer], /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.BlockCollection::SetAt(System.UInt32,Microsoft.UI.Xaml.Documents.Block)
    def set_at(self, index: winrt.system.UInt32, value: Block, /) -> None: ...
    # System.UInt32 Microsoft.UI.Xaml.Documents.BlockCollection::get_Size()
    @_property
    def size(self) -> winrt.system.UInt32: ...

@typing.final
class Bold(Span):
    def __new__(cls: typing.Type[Self]) -> Self: ...

@typing.final
class Glyphs_Static(microsoft_ui_xaml.FrameworkElement_Static):
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Glyphs::get_ColorFontPaletteIndexProperty()
    @_property
    def color_font_palette_index_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Glyphs::get_FillProperty()
    @_property
    def fill_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Glyphs::get_FontRenderingEmSizeProperty()
    @_property
    def font_rendering_em_size_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Glyphs::get_FontUriProperty()
    @_property
    def font_uri_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Glyphs::get_IndicesProperty()
    @_property
    def indices_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Glyphs::get_IsColorFontEnabledProperty()
    @_property
    def is_color_font_enabled_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Glyphs::get_OriginXProperty()
    @_property
    def origin_x_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Glyphs::get_OriginYProperty()
    @_property
    def origin_y_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Glyphs::get_StyleSimulationsProperty()
    @_property
    def style_simulations_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Glyphs::get_UnicodeStringProperty()
    @_property
    def unicode_string_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...

@typing.final
class Glyphs(microsoft_ui_xaml.FrameworkElement, metaclass=Glyphs_Static):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # System.String Microsoft.UI.Xaml.Documents.Glyphs::get_UnicodeString()
    @_property
    def unicode_string(self) -> str: ...
    # System.Void Microsoft.UI.Xaml.Documents.Glyphs::put_UnicodeString(System.String)
    @unicode_string.setter
    def unicode_string(self, value: str) -> None: ...
    # Microsoft.UI.Xaml.Media.StyleSimulations Microsoft.UI.Xaml.Documents.Glyphs::get_StyleSimulations()
    @_property
    def style_simulations(self) -> microsoft_ui_xaml_media.StyleSimulations: ...
    # System.Void Microsoft.UI.Xaml.Documents.Glyphs::put_StyleSimulations(Microsoft.UI.Xaml.Media.StyleSimulations)
    @style_simulations.setter
    def style_simulations(self, value: microsoft_ui_xaml_media.StyleSimulations) -> None: ...
    # System.Double Microsoft.UI.Xaml.Documents.Glyphs::get_OriginY()
    @_property
    def origin_y(self) -> winrt.system.Double: ...
    # System.Void Microsoft.UI.Xaml.Documents.Glyphs::put_OriginY(System.Double)
    @origin_y.setter
    def origin_y(self, value: winrt.system.Double) -> None: ...
    # System.Double Microsoft.UI.Xaml.Documents.Glyphs::get_OriginX()
    @_property
    def origin_x(self) -> winrt.system.Double: ...
    # System.Void Microsoft.UI.Xaml.Documents.Glyphs::put_OriginX(System.Double)
    @origin_x.setter
    def origin_x(self, value: winrt.system.Double) -> None: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Glyphs::get_IsColorFontEnabled()
    @_property
    def is_color_font_enabled(self) -> bool: ...
    # System.Void Microsoft.UI.Xaml.Documents.Glyphs::put_IsColorFontEnabled(System.Boolean)
    @is_color_font_enabled.setter
    def is_color_font_enabled(self, value: bool) -> None: ...
    # System.String Microsoft.UI.Xaml.Documents.Glyphs::get_Indices()
    @_property
    def indices(self) -> str: ...
    # System.Void Microsoft.UI.Xaml.Documents.Glyphs::put_Indices(System.String)
    @indices.setter
    def indices(self, value: str) -> None: ...
    # Windows.Foundation.Uri Microsoft.UI.Xaml.Documents.Glyphs::get_FontUri()
    @_property
    def font_uri(self) -> windows_foundation.Uri: ...
    # System.Void Microsoft.UI.Xaml.Documents.Glyphs::put_FontUri(Windows.Foundation.Uri)
    @font_uri.setter
    def font_uri(self, value: windows_foundation.Uri) -> None: ...
    # System.Double Microsoft.UI.Xaml.Documents.Glyphs::get_FontRenderingEmSize()
    @_property
    def font_rendering_em_size(self) -> winrt.system.Double: ...
    # System.Void Microsoft.UI.Xaml.Documents.Glyphs::put_FontRenderingEmSize(System.Double)
    @font_rendering_em_size.setter
    def font_rendering_em_size(self, value: winrt.system.Double) -> None: ...
    # Microsoft.UI.Xaml.Media.Brush Microsoft.UI.Xaml.Documents.Glyphs::get_Fill()
    @_property
    def fill(self) -> microsoft_ui_xaml_media.Brush: ...
    # System.Void Microsoft.UI.Xaml.Documents.Glyphs::put_Fill(Microsoft.UI.Xaml.Media.Brush)
    @fill.setter
    def fill(self, value: microsoft_ui_xaml_media.Brush) -> None: ...
    # System.Int32 Microsoft.UI.Xaml.Documents.Glyphs::get_ColorFontPaletteIndex()
    @_property
    def color_font_palette_index(self) -> winrt.system.Int32: ...
    # System.Void Microsoft.UI.Xaml.Documents.Glyphs::put_ColorFontPaletteIndex(System.Int32)
    @color_font_palette_index.setter
    def color_font_palette_index(self, value: winrt.system.Int32) -> None: ...

@typing.final
class Hyperlink_Static(Span_Static):
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_ElementSoundModeProperty()
    @_property
    def element_sound_mode_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_FocusStateProperty()
    @_property
    def focus_state_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_IsTabStopProperty()
    @_property
    def is_tab_stop_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_NavigateUriProperty()
    @_property
    def navigate_uri_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_TabIndexProperty()
    @_property
    def tab_index_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_UnderlineStyleProperty()
    @_property
    def underline_style_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusDownNavigationStrategyProperty()
    @_property
    def x_y_focus_down_navigation_strategy_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusDownProperty()
    @_property
    def x_y_focus_down_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusLeftNavigationStrategyProperty()
    @_property
    def x_y_focus_left_navigation_strategy_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusLeftProperty()
    @_property
    def x_y_focus_left_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusRightNavigationStrategyProperty()
    @_property
    def x_y_focus_right_navigation_strategy_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusRightProperty()
    @_property
    def x_y_focus_right_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusUpNavigationStrategyProperty()
    @_property
    def x_y_focus_up_navigation_strategy_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusUpProperty()
    @_property
    def x_y_focus_up_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...

@typing.final
class Hyperlink(Span, metaclass=Hyperlink_Static):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Hyperlink::Focus(Microsoft.UI.Xaml.FocusState)
    def focus(self, value: microsoft_ui_xaml.FocusState, /) -> bool: ...
    # Windows.Foundation.EventRegistrationToken Microsoft.UI.Xaml.Documents.Hyperlink::add_Click(Windows.Foundation.TypedEventHandler`2<Microsoft.UI.Xaml.Documents.Hyperlink,Microsoft.UI.Xaml.Documents.HyperlinkClickEventArgs>)
    def add_click(self, handler: windows_foundation.TypedEventHandler[Hyperlink, HyperlinkClickEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::remove_Click(Windows.Foundation.EventRegistrationToken)
    def remove_click(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Microsoft.UI.Xaml.Documents.Hyperlink::add_GotFocus(Microsoft.UI.Xaml.RoutedEventHandler)
    def add_got_focus(self, handler: microsoft_ui_xaml.RoutedEventHandler, /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::remove_GotFocus(Windows.Foundation.EventRegistrationToken)
    def remove_got_focus(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Microsoft.UI.Xaml.Documents.Hyperlink::add_LostFocus(Microsoft.UI.Xaml.RoutedEventHandler)
    def add_lost_focus(self, handler: microsoft_ui_xaml.RoutedEventHandler, /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::remove_LostFocus(Windows.Foundation.EventRegistrationToken)
    def remove_lost_focus(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusUpNavigationStrategy()
    @_property
    def x_y_focus_up_navigation_strategy(self) -> microsoft_ui_xaml_input.XYFocusNavigationStrategy: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_XYFocusUpNavigationStrategy(Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy)
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: microsoft_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    # Microsoft.UI.Xaml.DependencyObject Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusUp()
    @_property
    def x_y_focus_up(self) -> microsoft_ui_xaml.DependencyObject: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_XYFocusUp(Microsoft.UI.Xaml.DependencyObject)
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: microsoft_ui_xaml.DependencyObject) -> None: ...
    # Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusRightNavigationStrategy()
    @_property
    def x_y_focus_right_navigation_strategy(self) -> microsoft_ui_xaml_input.XYFocusNavigationStrategy: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_XYFocusRightNavigationStrategy(Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy)
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: microsoft_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    # Microsoft.UI.Xaml.DependencyObject Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusRight()
    @_property
    def x_y_focus_right(self) -> microsoft_ui_xaml.DependencyObject: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_XYFocusRight(Microsoft.UI.Xaml.DependencyObject)
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: microsoft_ui_xaml.DependencyObject) -> None: ...
    # Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusLeftNavigationStrategy()
    @_property
    def x_y_focus_left_navigation_strategy(self) -> microsoft_ui_xaml_input.XYFocusNavigationStrategy: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_XYFocusLeftNavigationStrategy(Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy)
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: microsoft_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    # Microsoft.UI.Xaml.DependencyObject Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusLeft()
    @_property
    def x_y_focus_left(self) -> microsoft_ui_xaml.DependencyObject: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_XYFocusLeft(Microsoft.UI.Xaml.DependencyObject)
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: microsoft_ui_xaml.DependencyObject) -> None: ...
    # Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusDownNavigationStrategy()
    @_property
    def x_y_focus_down_navigation_strategy(self) -> microsoft_ui_xaml_input.XYFocusNavigationStrategy: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_XYFocusDownNavigationStrategy(Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy)
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: microsoft_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    # Microsoft.UI.Xaml.DependencyObject Microsoft.UI.Xaml.Documents.Hyperlink::get_XYFocusDown()
    @_property
    def x_y_focus_down(self) -> microsoft_ui_xaml.DependencyObject: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_XYFocusDown(Microsoft.UI.Xaml.DependencyObject)
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: microsoft_ui_xaml.DependencyObject) -> None: ...
    # Microsoft.UI.Xaml.Documents.UnderlineStyle Microsoft.UI.Xaml.Documents.Hyperlink::get_UnderlineStyle()
    @_property
    def underline_style(self) -> UnderlineStyle: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_UnderlineStyle(Microsoft.UI.Xaml.Documents.UnderlineStyle)
    @underline_style.setter
    def underline_style(self, value: UnderlineStyle) -> None: ...
    # System.Int32 Microsoft.UI.Xaml.Documents.Hyperlink::get_TabIndex()
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_TabIndex(System.Int32)
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    # Windows.Foundation.Uri Microsoft.UI.Xaml.Documents.Hyperlink::get_NavigateUri()
    @_property
    def navigate_uri(self) -> windows_foundation.Uri: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_NavigateUri(Windows.Foundation.Uri)
    @navigate_uri.setter
    def navigate_uri(self, value: windows_foundation.Uri) -> None: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Hyperlink::get_IsTabStop()
    @_property
    def is_tab_stop(self) -> bool: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_IsTabStop(System.Boolean)
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    # Microsoft.UI.Xaml.ElementSoundMode Microsoft.UI.Xaml.Documents.Hyperlink::get_ElementSoundMode()
    @_property
    def element_sound_mode(self) -> microsoft_ui_xaml.ElementSoundMode: ...
    # System.Void Microsoft.UI.Xaml.Documents.Hyperlink::put_ElementSoundMode(Microsoft.UI.Xaml.ElementSoundMode)
    @element_sound_mode.setter
    def element_sound_mode(self, value: microsoft_ui_xaml.ElementSoundMode) -> None: ...
    # Microsoft.UI.Xaml.FocusState Microsoft.UI.Xaml.Documents.Hyperlink::get_FocusState()
    @_property
    def focus_state(self) -> microsoft_ui_xaml.FocusState: ...

@typing.final
class HyperlinkClickEventArgs(microsoft_ui_xaml.RoutedEventArgs):
    pass

class Inline_Static(TextElement_Static):
    pass

class Inline(TextElement, metaclass=Inline_Static):
    pass

@typing.final
class InlineCollection(winrt.system.Object, winrt._winrt.MutableSequence[Inline]):
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[Inline]: ...
    @typing.overload
    def __getitem__(self, index: typing.SupportsIndex) -> Inline: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winrt.system.Array[Inline]: ...
    @typing.overload
    def __delitem__(self, index: typing.SupportsIndex) -> None: ...
    @typing.overload
    def __delitem__(self, index: slice) -> None: ...
    @typing.overload
    def __setitem__(self, index: typing.SupportsIndex, value: Inline) -> None: ...
    @typing.overload
    def __setitem__(self, index: slice, value: typing.Iterable[Inline]) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.InlineCollection::Append(Microsoft.UI.Xaml.Documents.Inline)
    def append(self, value: Inline, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.InlineCollection::Clear()
    def clear(self) -> None: ...
    # Windows.Foundation.Collections.IIterator`1<Microsoft.UI.Xaml.Documents.Inline> Microsoft.UI.Xaml.Documents.InlineCollection::First()
    def first(self) -> windows_foundation_collections.IIterator[Inline]: ...
    # Microsoft.UI.Xaml.Documents.Inline Microsoft.UI.Xaml.Documents.InlineCollection::GetAt(System.UInt32)
    def get_at(self, index: winrt.system.UInt32, /) -> Inline: ...
    # System.UInt32 Microsoft.UI.Xaml.Documents.InlineCollection::GetMany(System.UInt32,Microsoft.UI.Xaml.Documents.Inline[])
    def get_many(self, start_index: winrt.system.UInt32, items: typing.Union[winrt.system.Array[Inline], winrt.system.WriteableBuffer], /) -> winrt.system.UInt32: ...
    # Windows.Foundation.Collections.IVectorView`1<Microsoft.UI.Xaml.Documents.Inline> Microsoft.UI.Xaml.Documents.InlineCollection::GetView()
    def get_view(self) -> typing.Sequence[Inline]: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.InlineCollection::IndexOf(Microsoft.UI.Xaml.Documents.Inline,System.UInt32&)
    def index_of(self, value: Inline, /) -> typing.Tuple[bool, winrt.system.UInt32]: ...
    # System.Void Microsoft.UI.Xaml.Documents.InlineCollection::InsertAt(System.UInt32,Microsoft.UI.Xaml.Documents.Inline)
    def insert_at(self, index: winrt.system.UInt32, value: Inline, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.InlineCollection::RemoveAt(System.UInt32)
    def remove_at(self, index: winrt.system.UInt32, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.InlineCollection::RemoveAtEnd()
    def remove_at_end(self) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.InlineCollection::ReplaceAll(Microsoft.UI.Xaml.Documents.Inline[])
    def replace_all(self, items: typing.Union[winrt.system.Array[Inline], winrt.system.ReadableBuffer], /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.InlineCollection::SetAt(System.UInt32,Microsoft.UI.Xaml.Documents.Inline)
    def set_at(self, index: winrt.system.UInt32, value: Inline, /) -> None: ...
    # System.UInt32 Microsoft.UI.Xaml.Documents.InlineCollection::get_Size()
    @_property
    def size(self) -> winrt.system.UInt32: ...

@typing.final
class InlineUIContainer(Inline):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Microsoft.UI.Xaml.UIElement Microsoft.UI.Xaml.Documents.InlineUIContainer::get_Child()
    @_property
    def child(self) -> microsoft_ui_xaml.UIElement: ...
    # System.Void Microsoft.UI.Xaml.Documents.InlineUIContainer::put_Child(Microsoft.UI.Xaml.UIElement)
    @child.setter
    def child(self, value: microsoft_ui_xaml.UIElement) -> None: ...

@typing.final
class Italic(Span):
    def __new__(cls: typing.Type[Self]) -> Self: ...

@typing.final
class LineBreak(Inline):
    def __new__(cls: typing.Type[Self]) -> Self: ...

@typing.final
class Paragraph_Static(Block_Static):
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Paragraph::get_TextIndentProperty()
    @_property
    def text_indent_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...

@typing.final
class Paragraph(Block, metaclass=Paragraph_Static):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # System.Double Microsoft.UI.Xaml.Documents.Paragraph::get_TextIndent()
    @_property
    def text_indent(self) -> winrt.system.Double: ...
    # System.Void Microsoft.UI.Xaml.Documents.Paragraph::put_TextIndent(System.Double)
    @text_indent.setter
    def text_indent(self, value: winrt.system.Double) -> None: ...
    # Microsoft.UI.Xaml.Documents.InlineCollection Microsoft.UI.Xaml.Documents.Paragraph::get_Inlines()
    @_property
    def inlines(self) -> InlineCollection: ...

@typing.final
class Run_Static(Inline_Static):
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Run::get_FlowDirectionProperty()
    @_property
    def flow_direction_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...

@typing.final
class Run(Inline, metaclass=Run_Static):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # System.String Microsoft.UI.Xaml.Documents.Run::get_Text()
    @_property
    def text(self) -> str: ...
    # System.Void Microsoft.UI.Xaml.Documents.Run::put_Text(System.String)
    @text.setter
    def text(self, value: str) -> None: ...
    # Microsoft.UI.Xaml.FlowDirection Microsoft.UI.Xaml.Documents.Run::get_FlowDirection()
    @_property
    def flow_direction(self) -> microsoft_ui_xaml.FlowDirection: ...
    # System.Void Microsoft.UI.Xaml.Documents.Run::put_FlowDirection(Microsoft.UI.Xaml.FlowDirection)
    @flow_direction.setter
    def flow_direction(self, value: microsoft_ui_xaml.FlowDirection) -> None: ...

class Span_Static(Inline_Static):
    pass

class Span(Inline, metaclass=Span_Static):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Microsoft.UI.Xaml.Documents.InlineCollection Microsoft.UI.Xaml.Documents.Span::get_Inlines()
    @_property
    def inlines(self) -> InlineCollection: ...
    # System.Void Microsoft.UI.Xaml.Documents.Span::put_Inlines(Microsoft.UI.Xaml.Documents.InlineCollection)
    @inlines.setter
    @typing.final
    def inlines(self, value: InlineCollection) -> None: ...

class TextElement_Static(microsoft_ui_xaml.DependencyObject_Static):
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_AccessKeyProperty()
    @_property
    @typing.final
    def access_key_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_AccessKeyScopeOwnerProperty()
    @_property
    @typing.final
    def access_key_scope_owner_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_AllowFocusOnInteractionProperty()
    @_property
    @typing.final
    def allow_focus_on_interaction_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_CharacterSpacingProperty()
    @_property
    @typing.final
    def character_spacing_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_ExitDisplayModeOnAccessKeyInvokedProperty()
    @_property
    @typing.final
    def exit_display_mode_on_access_key_invoked_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_FontFamilyProperty()
    @_property
    @typing.final
    def font_family_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_FontSizeProperty()
    @_property
    @typing.final
    def font_size_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_FontStretchProperty()
    @_property
    @typing.final
    def font_stretch_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_FontStyleProperty()
    @_property
    @typing.final
    def font_style_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_FontWeightProperty()
    @_property
    @typing.final
    def font_weight_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_ForegroundProperty()
    @_property
    @typing.final
    def foreground_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_IsAccessKeyScopeProperty()
    @_property
    @typing.final
    def is_access_key_scope_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_IsTextScaleFactorEnabledProperty()
    @_property
    @typing.final
    def is_text_scale_factor_enabled_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_KeyTipHorizontalOffsetProperty()
    @_property
    @typing.final
    def key_tip_horizontal_offset_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_KeyTipPlacementModeProperty()
    @_property
    @typing.final
    def key_tip_placement_mode_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_KeyTipVerticalOffsetProperty()
    @_property
    @typing.final
    def key_tip_vertical_offset_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_LanguageProperty()
    @_property
    @typing.final
    def language_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextElement::get_TextDecorationsProperty()
    @_property
    @typing.final
    def text_decorations_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...

class TextElement(microsoft_ui_xaml.DependencyObject, metaclass=TextElement_Static):
    @typing.final
    # System.Object Microsoft.UI.Xaml.Documents.TextElement::FindName(System.String)
    def find_name(self, name: str, /) -> winrt.system.Object: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::OnDisconnectVisualChildren()
    def _on_disconnect_visual_children(self) -> None: ...
    @typing.final
    # Windows.Foundation.EventRegistrationToken Microsoft.UI.Xaml.Documents.TextElement::add_AccessKeyDisplayDismissed(Windows.Foundation.TypedEventHandler`2<Microsoft.UI.Xaml.Documents.TextElement,Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs>)
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[TextElement, microsoft_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    @typing.final
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::remove_AccessKeyDisplayDismissed(Windows.Foundation.EventRegistrationToken)
    def remove_access_key_display_dismissed(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    @typing.final
    # Windows.Foundation.EventRegistrationToken Microsoft.UI.Xaml.Documents.TextElement::add_AccessKeyDisplayRequested(Windows.Foundation.TypedEventHandler`2<Microsoft.UI.Xaml.Documents.TextElement,Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs>)
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[TextElement, microsoft_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    @typing.final
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::remove_AccessKeyDisplayRequested(Windows.Foundation.EventRegistrationToken)
    def remove_access_key_display_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    @typing.final
    # Windows.Foundation.EventRegistrationToken Microsoft.UI.Xaml.Documents.TextElement::add_AccessKeyInvoked(Windows.Foundation.TypedEventHandler`2<Microsoft.UI.Xaml.Documents.TextElement,Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs>)
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[TextElement, microsoft_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    @typing.final
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::remove_AccessKeyInvoked(Windows.Foundation.EventRegistrationToken)
    def remove_access_key_invoked(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Microsoft.UI.Xaml.XamlRoot Microsoft.UI.Xaml.Documents.TextElement::get_XamlRoot()
    @_property
    def xaml_root(self) -> microsoft_ui_xaml.XamlRoot: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_XamlRoot(Microsoft.UI.Xaml.XamlRoot)
    @xaml_root.setter
    @typing.final
    def xaml_root(self, value: microsoft_ui_xaml.XamlRoot) -> None: ...
    # Windows.UI.Text.TextDecorations Microsoft.UI.Xaml.Documents.TextElement::get_TextDecorations()
    @_property
    def text_decorations(self) -> windows_ui_text.TextDecorations: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_TextDecorations(Windows.UI.Text.TextDecorations)
    @text_decorations.setter
    @typing.final
    def text_decorations(self, value: windows_ui_text.TextDecorations) -> None: ...
    # System.String Microsoft.UI.Xaml.Documents.TextElement::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_Language(System.String)
    @language.setter
    @typing.final
    def language(self, value: str) -> None: ...
    # System.Double Microsoft.UI.Xaml.Documents.TextElement::get_KeyTipVerticalOffset()
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_KeyTipVerticalOffset(System.Double)
    @key_tip_vertical_offset.setter
    @typing.final
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    # Microsoft.UI.Xaml.Input.KeyTipPlacementMode Microsoft.UI.Xaml.Documents.TextElement::get_KeyTipPlacementMode()
    @_property
    def key_tip_placement_mode(self) -> microsoft_ui_xaml_input.KeyTipPlacementMode: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_KeyTipPlacementMode(Microsoft.UI.Xaml.Input.KeyTipPlacementMode)
    @key_tip_placement_mode.setter
    @typing.final
    def key_tip_placement_mode(self, value: microsoft_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    # System.Double Microsoft.UI.Xaml.Documents.TextElement::get_KeyTipHorizontalOffset()
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_KeyTipHorizontalOffset(System.Double)
    @key_tip_horizontal_offset.setter
    @typing.final
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.TextElement::get_IsTextScaleFactorEnabled()
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_IsTextScaleFactorEnabled(System.Boolean)
    @is_text_scale_factor_enabled.setter
    @typing.final
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.TextElement::get_IsAccessKeyScope()
    @_property
    def is_access_key_scope(self) -> bool: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_IsAccessKeyScope(System.Boolean)
    @is_access_key_scope.setter
    @typing.final
    def is_access_key_scope(self, value: bool) -> None: ...
    # Microsoft.UI.Xaml.Media.Brush Microsoft.UI.Xaml.Documents.TextElement::get_Foreground()
    @_property
    def foreground(self) -> microsoft_ui_xaml_media.Brush: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_Foreground(Microsoft.UI.Xaml.Media.Brush)
    @foreground.setter
    @typing.final
    def foreground(self, value: microsoft_ui_xaml_media.Brush) -> None: ...
    # Windows.UI.Text.FontWeight Microsoft.UI.Xaml.Documents.TextElement::get_FontWeight()
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_FontWeight(Windows.UI.Text.FontWeight)
    @font_weight.setter
    @typing.final
    def font_weight(self, value: typing.Union[windows_ui_text.FontWeight, typing.Tuple[winrt.system.UInt16]]) -> None: ...
    # Windows.UI.Text.FontStyle Microsoft.UI.Xaml.Documents.TextElement::get_FontStyle()
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_FontStyle(Windows.UI.Text.FontStyle)
    @font_style.setter
    @typing.final
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    # Windows.UI.Text.FontStretch Microsoft.UI.Xaml.Documents.TextElement::get_FontStretch()
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_FontStretch(Windows.UI.Text.FontStretch)
    @font_stretch.setter
    @typing.final
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    # System.Double Microsoft.UI.Xaml.Documents.TextElement::get_FontSize()
    @_property
    def font_size(self) -> winrt.system.Double: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_FontSize(System.Double)
    @font_size.setter
    @typing.final
    def font_size(self, value: winrt.system.Double) -> None: ...
    # Microsoft.UI.Xaml.Media.FontFamily Microsoft.UI.Xaml.Documents.TextElement::get_FontFamily()
    @_property
    def font_family(self) -> microsoft_ui_xaml_media.FontFamily: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_FontFamily(Microsoft.UI.Xaml.Media.FontFamily)
    @font_family.setter
    @typing.final
    def font_family(self, value: microsoft_ui_xaml_media.FontFamily) -> None: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.TextElement::get_ExitDisplayModeOnAccessKeyInvoked()
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_ExitDisplayModeOnAccessKeyInvoked(System.Boolean)
    @exit_display_mode_on_access_key_invoked.setter
    @typing.final
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    # System.Int32 Microsoft.UI.Xaml.Documents.TextElement::get_CharacterSpacing()
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_CharacterSpacing(System.Int32)
    @character_spacing.setter
    @typing.final
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.TextElement::get_AllowFocusOnInteraction()
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_AllowFocusOnInteraction(System.Boolean)
    @allow_focus_on_interaction.setter
    @typing.final
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    # Microsoft.UI.Xaml.DependencyObject Microsoft.UI.Xaml.Documents.TextElement::get_AccessKeyScopeOwner()
    @_property
    def access_key_scope_owner(self) -> microsoft_ui_xaml.DependencyObject: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_AccessKeyScopeOwner(Microsoft.UI.Xaml.DependencyObject)
    @access_key_scope_owner.setter
    @typing.final
    def access_key_scope_owner(self, value: microsoft_ui_xaml.DependencyObject) -> None: ...
    # System.String Microsoft.UI.Xaml.Documents.TextElement::get_AccessKey()
    @_property
    def access_key(self) -> str: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextElement::put_AccessKey(System.String)
    @access_key.setter
    @typing.final
    def access_key(self, value: str) -> None: ...
    # Microsoft.UI.Xaml.Documents.TextPointer Microsoft.UI.Xaml.Documents.TextElement::get_ContentEnd()
    @_property
    @typing.final
    def content_end(self) -> TextPointer: ...
    # Microsoft.UI.Xaml.Documents.TextPointer Microsoft.UI.Xaml.Documents.TextElement::get_ContentStart()
    @_property
    @typing.final
    def content_start(self) -> TextPointer: ...
    # Microsoft.UI.Xaml.Documents.TextPointer Microsoft.UI.Xaml.Documents.TextElement::get_ElementEnd()
    @_property
    @typing.final
    def element_end(self) -> TextPointer: ...
    # Microsoft.UI.Xaml.Documents.TextPointer Microsoft.UI.Xaml.Documents.TextElement::get_ElementStart()
    @_property
    @typing.final
    def element_start(self) -> TextPointer: ...
    # System.String Microsoft.UI.Xaml.Documents.TextElement::get_Name()
    @_property
    @typing.final
    def name(self) -> str: ...

class TextHighlighter_Static(winrt._winrt.IInspectable_Static):
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextHighlighter::get_BackgroundProperty()
    @_property
    @typing.final
    def background_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.TextHighlighter::get_ForegroundProperty()
    @_property
    @typing.final
    def foreground_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...

class TextHighlighter(winrt.system.Object, metaclass=TextHighlighter_Static):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Microsoft.UI.Xaml.Media.Brush Microsoft.UI.Xaml.Documents.TextHighlighter::get_Foreground()
    @_property
    def foreground(self) -> microsoft_ui_xaml_media.Brush: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextHighlighter::put_Foreground(Microsoft.UI.Xaml.Media.Brush)
    @foreground.setter
    @typing.final
    def foreground(self, value: microsoft_ui_xaml_media.Brush) -> None: ...
    # Microsoft.UI.Xaml.Media.Brush Microsoft.UI.Xaml.Documents.TextHighlighter::get_Background()
    @_property
    def background(self) -> microsoft_ui_xaml_media.Brush: ...
    # System.Void Microsoft.UI.Xaml.Documents.TextHighlighter::put_Background(Microsoft.UI.Xaml.Media.Brush)
    @background.setter
    @typing.final
    def background(self, value: microsoft_ui_xaml_media.Brush) -> None: ...
    # Windows.Foundation.Collections.IVector`1<Microsoft.UI.Xaml.Documents.TextRange> Microsoft.UI.Xaml.Documents.TextHighlighter::get_Ranges()
    @_property
    @typing.final
    def ranges(self) -> typing.MutableSequence[TextRange]: ...

class TextHighlighterBase_Static(microsoft_ui_xaml.DependencyObject_Static):
    pass

class TextHighlighterBase(microsoft_ui_xaml.DependencyObject, metaclass=TextHighlighterBase_Static):
    pass

@typing.final
class TextPointer(winrt.system.Object):
    # Windows.Foundation.Rect Microsoft.UI.Xaml.Documents.TextPointer::GetCharacterRect(Microsoft.UI.Xaml.Documents.LogicalDirection)
    def get_character_rect(self, direction: LogicalDirection, /) -> windows_foundation.Rect: ...
    # Microsoft.UI.Xaml.Documents.TextPointer Microsoft.UI.Xaml.Documents.TextPointer::GetPositionAtOffset(System.Int32,Microsoft.UI.Xaml.Documents.LogicalDirection)
    def get_position_at_offset(self, offset: winrt.system.Int32, direction: LogicalDirection, /) -> TextPointer: ...
    # Microsoft.UI.Xaml.Documents.LogicalDirection Microsoft.UI.Xaml.Documents.TextPointer::get_LogicalDirection()
    @_property
    def logical_direction(self) -> LogicalDirection: ...
    # System.Int32 Microsoft.UI.Xaml.Documents.TextPointer::get_Offset()
    @_property
    def offset(self) -> winrt.system.Int32: ...
    # Microsoft.UI.Xaml.DependencyObject Microsoft.UI.Xaml.Documents.TextPointer::get_Parent()
    @_property
    def parent(self) -> microsoft_ui_xaml.DependencyObject: ...
    # Microsoft.UI.Xaml.FrameworkElement Microsoft.UI.Xaml.Documents.TextPointer::get_VisualParent()
    @_property
    def visual_parent(self) -> microsoft_ui_xaml.FrameworkElement: ...

@typing.final
class Typography_Static(winrt._winrt.IInspectable_Static):
    # System.Int32 Microsoft.UI.Xaml.Documents.Typography::GetAnnotationAlternates(Microsoft.UI.Xaml.DependencyObject)
    def get_annotation_alternates(cls, element: microsoft_ui_xaml.DependencyObject, /) -> winrt.system.Int32: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetCapitalSpacing(Microsoft.UI.Xaml.DependencyObject)
    def get_capital_spacing(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # Microsoft.UI.Xaml.FontCapitals Microsoft.UI.Xaml.Documents.Typography::GetCapitals(Microsoft.UI.Xaml.DependencyObject)
    def get_capitals(cls, element: microsoft_ui_xaml.DependencyObject, /) -> microsoft_ui_xaml.FontCapitals: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetCaseSensitiveForms(Microsoft.UI.Xaml.DependencyObject)
    def get_case_sensitive_forms(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetContextualAlternates(Microsoft.UI.Xaml.DependencyObject)
    def get_contextual_alternates(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetContextualLigatures(Microsoft.UI.Xaml.DependencyObject)
    def get_contextual_ligatures(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Int32 Microsoft.UI.Xaml.Documents.Typography::GetContextualSwashes(Microsoft.UI.Xaml.DependencyObject)
    def get_contextual_swashes(cls, element: microsoft_ui_xaml.DependencyObject, /) -> winrt.system.Int32: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetDiscretionaryLigatures(Microsoft.UI.Xaml.DependencyObject)
    def get_discretionary_ligatures(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetEastAsianExpertForms(Microsoft.UI.Xaml.DependencyObject)
    def get_east_asian_expert_forms(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # Microsoft.UI.Xaml.FontEastAsianLanguage Microsoft.UI.Xaml.Documents.Typography::GetEastAsianLanguage(Microsoft.UI.Xaml.DependencyObject)
    def get_east_asian_language(cls, element: microsoft_ui_xaml.DependencyObject, /) -> microsoft_ui_xaml.FontEastAsianLanguage: ...
    # Microsoft.UI.Xaml.FontEastAsianWidths Microsoft.UI.Xaml.Documents.Typography::GetEastAsianWidths(Microsoft.UI.Xaml.DependencyObject)
    def get_east_asian_widths(cls, element: microsoft_ui_xaml.DependencyObject, /) -> microsoft_ui_xaml.FontEastAsianWidths: ...
    # Microsoft.UI.Xaml.FontFraction Microsoft.UI.Xaml.Documents.Typography::GetFraction(Microsoft.UI.Xaml.DependencyObject)
    def get_fraction(cls, element: microsoft_ui_xaml.DependencyObject, /) -> microsoft_ui_xaml.FontFraction: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetHistoricalForms(Microsoft.UI.Xaml.DependencyObject)
    def get_historical_forms(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetHistoricalLigatures(Microsoft.UI.Xaml.DependencyObject)
    def get_historical_ligatures(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetKerning(Microsoft.UI.Xaml.DependencyObject)
    def get_kerning(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetMathematicalGreek(Microsoft.UI.Xaml.DependencyObject)
    def get_mathematical_greek(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # Microsoft.UI.Xaml.FontNumeralAlignment Microsoft.UI.Xaml.Documents.Typography::GetNumeralAlignment(Microsoft.UI.Xaml.DependencyObject)
    def get_numeral_alignment(cls, element: microsoft_ui_xaml.DependencyObject, /) -> microsoft_ui_xaml.FontNumeralAlignment: ...
    # Microsoft.UI.Xaml.FontNumeralStyle Microsoft.UI.Xaml.Documents.Typography::GetNumeralStyle(Microsoft.UI.Xaml.DependencyObject)
    def get_numeral_style(cls, element: microsoft_ui_xaml.DependencyObject, /) -> microsoft_ui_xaml.FontNumeralStyle: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetSlashedZero(Microsoft.UI.Xaml.DependencyObject)
    def get_slashed_zero(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStandardLigatures(Microsoft.UI.Xaml.DependencyObject)
    def get_standard_ligatures(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Int32 Microsoft.UI.Xaml.Documents.Typography::GetStandardSwashes(Microsoft.UI.Xaml.DependencyObject)
    def get_standard_swashes(cls, element: microsoft_ui_xaml.DependencyObject, /) -> winrt.system.Int32: ...
    # System.Int32 Microsoft.UI.Xaml.Documents.Typography::GetStylisticAlternates(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_alternates(cls, element: microsoft_ui_xaml.DependencyObject, /) -> winrt.system.Int32: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet1(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set1(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet10(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set10(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet11(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set11(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet12(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set12(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet13(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set13(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet14(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set14(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet15(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set15(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet16(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set16(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet17(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set17(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet18(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set18(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet19(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set19(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet2(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set2(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet20(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set20(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet3(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set3(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet4(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set4(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet5(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set5(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet6(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set6(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet7(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set7(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet8(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set8(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # System.Boolean Microsoft.UI.Xaml.Documents.Typography::GetStylisticSet9(Microsoft.UI.Xaml.DependencyObject)
    def get_stylistic_set9(cls, element: microsoft_ui_xaml.DependencyObject, /) -> bool: ...
    # Microsoft.UI.Xaml.FontVariants Microsoft.UI.Xaml.Documents.Typography::GetVariants(Microsoft.UI.Xaml.DependencyObject)
    def get_variants(cls, element: microsoft_ui_xaml.DependencyObject, /) -> microsoft_ui_xaml.FontVariants: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetAnnotationAlternates(Microsoft.UI.Xaml.DependencyObject,System.Int32)
    def set_annotation_alternates(cls, element: microsoft_ui_xaml.DependencyObject, value: winrt.system.Int32, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetCapitalSpacing(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_capital_spacing(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetCapitals(Microsoft.UI.Xaml.DependencyObject,Microsoft.UI.Xaml.FontCapitals)
    def set_capitals(cls, element: microsoft_ui_xaml.DependencyObject, value: microsoft_ui_xaml.FontCapitals, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetCaseSensitiveForms(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_case_sensitive_forms(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetContextualAlternates(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_contextual_alternates(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetContextualLigatures(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_contextual_ligatures(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetContextualSwashes(Microsoft.UI.Xaml.DependencyObject,System.Int32)
    def set_contextual_swashes(cls, element: microsoft_ui_xaml.DependencyObject, value: winrt.system.Int32, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetDiscretionaryLigatures(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_discretionary_ligatures(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetEastAsianExpertForms(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_east_asian_expert_forms(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetEastAsianLanguage(Microsoft.UI.Xaml.DependencyObject,Microsoft.UI.Xaml.FontEastAsianLanguage)
    def set_east_asian_language(cls, element: microsoft_ui_xaml.DependencyObject, value: microsoft_ui_xaml.FontEastAsianLanguage, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetEastAsianWidths(Microsoft.UI.Xaml.DependencyObject,Microsoft.UI.Xaml.FontEastAsianWidths)
    def set_east_asian_widths(cls, element: microsoft_ui_xaml.DependencyObject, value: microsoft_ui_xaml.FontEastAsianWidths, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetFraction(Microsoft.UI.Xaml.DependencyObject,Microsoft.UI.Xaml.FontFraction)
    def set_fraction(cls, element: microsoft_ui_xaml.DependencyObject, value: microsoft_ui_xaml.FontFraction, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetHistoricalForms(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_historical_forms(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetHistoricalLigatures(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_historical_ligatures(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetKerning(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_kerning(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetMathematicalGreek(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_mathematical_greek(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetNumeralAlignment(Microsoft.UI.Xaml.DependencyObject,Microsoft.UI.Xaml.FontNumeralAlignment)
    def set_numeral_alignment(cls, element: microsoft_ui_xaml.DependencyObject, value: microsoft_ui_xaml.FontNumeralAlignment, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetNumeralStyle(Microsoft.UI.Xaml.DependencyObject,Microsoft.UI.Xaml.FontNumeralStyle)
    def set_numeral_style(cls, element: microsoft_ui_xaml.DependencyObject, value: microsoft_ui_xaml.FontNumeralStyle, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetSlashedZero(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_slashed_zero(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStandardLigatures(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_standard_ligatures(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStandardSwashes(Microsoft.UI.Xaml.DependencyObject,System.Int32)
    def set_standard_swashes(cls, element: microsoft_ui_xaml.DependencyObject, value: winrt.system.Int32, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticAlternates(Microsoft.UI.Xaml.DependencyObject,System.Int32)
    def set_stylistic_alternates(cls, element: microsoft_ui_xaml.DependencyObject, value: winrt.system.Int32, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet1(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set1(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet10(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set10(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet11(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set11(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet12(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set12(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet13(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set13(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet14(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set14(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet15(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set15(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet16(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set16(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet17(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set17(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet18(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set18(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet19(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set19(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet2(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set2(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet20(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set20(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet3(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set3(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet4(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set4(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet5(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set5(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet6(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set6(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet7(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set7(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet8(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set8(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetStylisticSet9(Microsoft.UI.Xaml.DependencyObject,System.Boolean)
    def set_stylistic_set9(cls, element: microsoft_ui_xaml.DependencyObject, value: bool, /) -> None: ...
    # System.Void Microsoft.UI.Xaml.Documents.Typography::SetVariants(Microsoft.UI.Xaml.DependencyObject,Microsoft.UI.Xaml.FontVariants)
    def set_variants(cls, element: microsoft_ui_xaml.DependencyObject, value: microsoft_ui_xaml.FontVariants, /) -> None: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_AnnotationAlternatesProperty()
    @_property
    def annotation_alternates_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_CapitalSpacingProperty()
    @_property
    def capital_spacing_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_CapitalsProperty()
    @_property
    def capitals_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_CaseSensitiveFormsProperty()
    @_property
    def case_sensitive_forms_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_ContextualAlternatesProperty()
    @_property
    def contextual_alternates_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_ContextualLigaturesProperty()
    @_property
    def contextual_ligatures_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_ContextualSwashesProperty()
    @_property
    def contextual_swashes_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_DiscretionaryLigaturesProperty()
    @_property
    def discretionary_ligatures_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_EastAsianExpertFormsProperty()
    @_property
    def east_asian_expert_forms_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_EastAsianLanguageProperty()
    @_property
    def east_asian_language_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_EastAsianWidthsProperty()
    @_property
    def east_asian_widths_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_FractionProperty()
    @_property
    def fraction_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_HistoricalFormsProperty()
    @_property
    def historical_forms_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_HistoricalLigaturesProperty()
    @_property
    def historical_ligatures_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_KerningProperty()
    @_property
    def kerning_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_MathematicalGreekProperty()
    @_property
    def mathematical_greek_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_NumeralAlignmentProperty()
    @_property
    def numeral_alignment_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_NumeralStyleProperty()
    @_property
    def numeral_style_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_SlashedZeroProperty()
    @_property
    def slashed_zero_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StandardLigaturesProperty()
    @_property
    def standard_ligatures_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StandardSwashesProperty()
    @_property
    def standard_swashes_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticAlternatesProperty()
    @_property
    def stylistic_alternates_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet10Property()
    @_property
    def stylistic_set10_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet11Property()
    @_property
    def stylistic_set11_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet12Property()
    @_property
    def stylistic_set12_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet13Property()
    @_property
    def stylistic_set13_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet14Property()
    @_property
    def stylistic_set14_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet15Property()
    @_property
    def stylistic_set15_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet16Property()
    @_property
    def stylistic_set16_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet17Property()
    @_property
    def stylistic_set17_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet18Property()
    @_property
    def stylistic_set18_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet19Property()
    @_property
    def stylistic_set19_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet1Property()
    @_property
    def stylistic_set1_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet20Property()
    @_property
    def stylistic_set20_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet2Property()
    @_property
    def stylistic_set2_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet3Property()
    @_property
    def stylistic_set3_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet4Property()
    @_property
    def stylistic_set4_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet5Property()
    @_property
    def stylistic_set5_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet6Property()
    @_property
    def stylistic_set6_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet7Property()
    @_property
    def stylistic_set7_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet8Property()
    @_property
    def stylistic_set8_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_StylisticSet9Property()
    @_property
    def stylistic_set9_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...
    # Microsoft.UI.Xaml.DependencyProperty Microsoft.UI.Xaml.Documents.Typography::get_VariantsProperty()
    @_property
    def variants_property(cls) -> microsoft_ui_xaml.DependencyProperty: ...

@typing.final
class Typography(winrt.system.Object, metaclass=Typography_Static):
    pass

@typing.final
class Underline(Span):
    def __new__(cls: typing.Type[Self]) -> Self: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import enum

import winrt.system
from winui3._winui3_microsoft_ui_xaml_documents import (
    TextRange,
    Block,
    BlockCollection,
    Bold,
    Glyphs,
    Hyperlink,
    HyperlinkClickEventArgs,
    Inline,
    InlineCollection,
    InlineUIContainer,
    Italic,
    LineBreak,
    Paragraph,
    Run,
    Span,
    TextElement,
    TextHighlighter,
    TextHighlighterBase,
    TextPointer,
    Typography,
    Underline,
)
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from winui3._winui3_microsoft_ui_xaml_documents import (
        Block_Static,
        Inline_Static,
        Span_Static,
        TextElement_Static,
        TextHighlighter_Static,
        TextHighlighterBase_Static,
    )

__all__ = [
    "LogicalDirection",
    "UnderlineStyle",
    "TextRange",
    "Block",
    "BlockCollection",
    "Bold",
    "Glyphs",
    "Hyperlink",
    "HyperlinkClickEventArgs",
    "Inline",
    "InlineCollection",
    "InlineUIContainer",
    "Italic",
    "LineBreak",
    "Paragraph",
    "Run",
    "Span",
    "TextElement",
    "TextHighlighter",
    "TextHighlighterBase",
    "TextPointer",
    "Typography",
    "Underline",
]

class LogicalDirection(enum.IntEnum):
    BACKWARD = 0
    FORWARD = 1

class UnderlineStyle(enum.IntEnum):
    NONE = 0
    SINGLE = 1

winrt.system._mixin_mutable_sequence(BlockCollection)
winrt.system._mixin_mutable_sequence(InlineCollection)
